import { LanguageServerError, MessageKind } from './languageServerError';
import { RequestType, IRequestHandler, NotificationType, INotificationHandler, ResponseError, ErrorCodes } from 'vscode-jsonrpc';
import { InitializeParams, InitializeResult, InitializeError, ShutdownParams, ExitParams, DidChangeConfigurationParams, DidOpenTextDocumentParams, DidChangeTextDocumentParams, DidCloseTextDocumentParams, DidChangeFilesParams, FileEvent, FileChangeType, PublishDiagnosticsParams, Diagnostic, Severity, Position } from './protocol';
import { ISimpleTextDocument } from './textDocuments';
export { RequestType, IRequestHandler, NotificationType, INotificationHandler, InitializeResult, InitializeError, Diagnostic, Severity, Position, FileEvent, FileChangeType, ErrorCodes, ResponseError };
export { LanguageServerError, MessageKind };
export { ISimpleTextDocument };
import * as fm from './files';
export declare namespace Files {
    let uriToFilePath: typeof fm.uriToFilePath;
    let resolveModule: typeof fm.resolveModule;
}
export declare type Result<T> = T | Thenable<T>;
export interface IValidationRequestor {
    single(uri: string): boolean;
    all(): void;
}
export interface SingleFileValidator {
    initialize?(rootFolder: string): Result<InitializeResult | ResponseError<InitializeError>>;
    validate(document: ISimpleTextDocument): Result<Diagnostic[]>;
    onConfigurationChange?(settings: any, requestor: IValidationRequestor): void;
    onFileEvents?(changes: FileEvent[], requestor: IValidationRequestor): void;
    shutdown?(): void;
}
export interface RemoteConsole {
    error(message: string): any;
    warn(message: string): any;
    info(message: string): any;
    log(message: string): any;
}
export interface RemoteWindow {
    showErrorMessage(message: string): any;
    showWarningMessage(message: string): any;
    showInformationMessage(message: string): any;
}
export interface IConnection {
    onRequest<P, R, E>(type: RequestType<P, R, E>, handler: IRequestHandler<P, R, E>): void;
    sendNotification<P>(type: NotificationType<P>, params?: P): void;
    onNotification<P>(type: NotificationType<P>, handler: INotificationHandler<P>): void;
    onInitialize(handler: IRequestHandler<InitializeParams, InitializeResult, InitializeError>): void;
    onShutdown(handler: IRequestHandler<ShutdownParams, void, void>): void;
    onExit(handler: INotificationHandler<ExitParams>): void;
    console: RemoteConsole;
    window: RemoteWindow;
    onDidChangeConfiguration(handler: INotificationHandler<DidChangeConfigurationParams>): void;
    onDidChangeFiles(handler: INotificationHandler<DidChangeFilesParams>): void;
    onDidOpenTextDocument(handler: INotificationHandler<DidOpenTextDocumentParams>): void;
    onDidChangeTextDocument(handler: INotificationHandler<DidChangeTextDocumentParams>): void;
    onDidCloseTextDocument(handler: INotificationHandler<DidCloseTextDocumentParams>): void;
    publishDiagnostics(args: PublishDiagnosticsParams): void;
    dispose(): void;
}
export declare function createConnection(inputStream: NodeJS.ReadableStream, outputStream: NodeJS.WritableStream): IConnection;
export interface IValidatorConnection {
    console: RemoteConsole;
    window: RemoteWindow;
    onRequest<P, R, E>(type: RequestType<P, R, E>, handler: IRequestHandler<P, R, E>): void;
    sendNotification<P>(type: NotificationType<P>, params?: P): void;
    onNotification<P>(type: NotificationType<P>, handler: INotificationHandler<P>): void;
    run(handler: SingleFileValidator): void;
}
export declare function createValidatorConnection(inputStream: NodeJS.ReadableStream, outputStream: NodeJS.WritableStream): IValidatorConnection;
export declare function runSingleFileValidator(inputStream: NodeJS.ReadableStream, outputStream: NodeJS.WritableStream, handler: SingleFileValidator): void;
