import { RequestType, NotificationType } from 'vscode-jsonrpc';
export interface HostCapabilities {
}
export interface ServerCapabilities {
    incrementalTextDocumentSync?: boolean;
}
/**
 * The initialize command is send from the client to the worker.
 * It is send once as the first command after starting up the
 * worker.
 */
export declare namespace InitializeRequest {
    let type: RequestType<InitializeParams, InitializeResult, InitializeError>;
}
export interface InitializeParams {
    rootFolder: string;
    capabilities: HostCapabilities;
}
export interface InitializeResult {
    capabilities: ServerCapabilities;
}
export interface InitializeError {
    retry: boolean;
}
/**
 * The shutdown command is send from the client to the worker.
 * It is send once when the client descides to shutdown the
 * worker. The only event that is send after a shudown request
 * is the exit event.
 */
export declare namespace ShutdownRequest {
    let type: RequestType<ShutdownParams, void, void>;
}
export interface ShutdownParams {
}
/**
 * The exit event is send from the client to the worker to
 * ask the worker to exit its process.
 */
export declare namespace ExitNotification {
    let type: NotificationType<ExitParams>;
}
export interface ExitParams {
}
/**
 * The configuration change event is send from the client to the worker
 * when the client's configuration has changed. The event contains
 * the changed configuration as defined by the language worker statically
 * in it's extension manifest.
 */
export declare namespace DidChangeConfigurationNotification {
    let type: NotificationType<DidChangeConfigurationParams>;
}
export interface DidChangeConfigurationParams {
    settings: any;
}
export declare namespace MessageType {
    const Error: number;
    const Warning: number;
    const Info: number;
    const Log: number;
}
/**
 * The show message event is send from a worker to a client to ask
 * the client to display a particular message in the user interface
 */
export declare namespace ShowMessageNotification {
    let type: NotificationType<ShowMessageParams>;
}
export interface ShowMessageParams {
    type: number;
    message: string;
}
export declare namespace LogMessageNotification {
    let type: NotificationType<LogMessageParams>;
}
export interface LogMessageParams {
    type: number;
    message: string;
}
/**
 * Position in a text document expressed as (zero-based) line and character offset.
 */
export interface Position {
    /**
     * Line Position in a document (zero-based)
     */
    line: number;
    /**
     * Character offset on a line in a document (zero-based)
     */
    character: number;
}
/**
 * A range in a text document.
 */
export interface Range {
    /**
     * The range's start position
     */
    start: Position;
    /**
     * The range's end position
     */
    end: Position;
}
export interface TextDocumentIdentifier {
    /**
     * A URI identifying the resource in the client.
     */
    uri: string;
}
/**
 * The document event is send from the client to the worker to signal
 * newly opened, changed and closed documents.
 */
export declare namespace DidOpenTextDocumentNotification {
    let type: NotificationType<DidOpenTextDocumentParams>;
}
export interface DidOpenTextDocumentParams extends TextDocumentIdentifier {
    /**
     * The content of the opened document.
     */
    text: string;
}
export declare namespace DidChangeTextDocumentNotification {
    let type: NotificationType<DidChangeTextDocumentParams>;
}
/**
 * The arguments describing a change to a text document. If range and rangeLength are omitted
 * the new text is considered to be the full content of the document.
 */
export interface DidChangeTextDocumentParams extends TextDocumentIdentifier {
    /**
     * The range of the document that changed.
     */
    range?: Range;
    /**
     * The length of the range that got replaced.
     */
    rangeLength?: number;
    /**
     * The new text of the document.
     */
    text: string;
}
export declare namespace DidCloseTextDocumentNotification {
    let type: NotificationType<DidCloseTextDocumentParams>;
}
export interface DidCloseTextDocumentParams extends TextDocumentIdentifier {
}
export declare namespace DidChangeFilesNotification {
    let type: NotificationType<DidChangeFilesParams>;
}
export interface DidChangeFilesParams {
    changes: FileEvent[];
}
export declare namespace FileChangeType {
    let Created: number;
    let Changed: number;
    let Deleted: number;
}
export interface FileEvent {
    uri: string;
    type: number;
}
/**
 * Diagnostics notification are send from the worker to clients to signal
 * results of validation runs
 */
export declare namespace PublishDiagnosticsNotification {
    let type: NotificationType<PublishDiagnosticsParams>;
}
export interface PublishDiagnosticsParams {
    /**
     * The URI for which diagnostic information is reported.
     */
    uri: string;
    /**
     * An array of diagnostic information items.
     */
    diagnostics: Diagnostic[];
}
export declare namespace Severity {
    let Error: number;
    let Warning: number;
    let Information: number;
    let Hint: number;
}
/**
 * Item of diagnostic information found in a DiagnosticEvent message.
 */
export interface Diagnostic {
    /**
     * Starting position at which text appies.
     */
    start: Position;
    /**
     * The last position at which the text applies. Can be omitted.
     */
    end?: Position;
    /**
     * The diagnostic's severity. Can be omitted. If omitted it is up to the
     * client to interpret diagnostics as error, warning or info.
     */
    severity?: number;
    /**
     * The diagnostic code. Can be omitted.
     */
    code?: string;
    /**
     * The diagnostic message.
     */
    message: string;
}
