/*---------------------------------------------------------
 * Copyright (C) Microsoft Corporation. All rights reserved.
 *--------------------------------------------------------*/
'use strict';
/**
 * The initialize command is send from the client to the worker.
 * It is send once as the first command after starting up the
 * worker.
 */
var InitializeRequest;
(function (InitializeRequest) {
    InitializeRequest.type = { method: 'initialize' };
})(InitializeRequest = exports.InitializeRequest || (exports.InitializeRequest = {}));
/**
 * The shutdown command is send from the client to the worker.
 * It is send once when the client descides to shutdown the
 * worker. The only event that is send after a shudown request
 * is the exit event.
 */
var ShutdownRequest;
(function (ShutdownRequest) {
    ShutdownRequest.type = { method: 'shutdown' };
})(ShutdownRequest = exports.ShutdownRequest || (exports.ShutdownRequest = {}));
/**
 * The exit event is send from the client to the worker to
 * ask the worker to exit its process.
 */
var ExitNotification;
(function (ExitNotification) {
    ExitNotification.type = { method: 'exit' };
})(ExitNotification = exports.ExitNotification || (exports.ExitNotification = {}));
/**
 * The configuration change event is send from the client to the worker
 * when the client's configuration has changed. The event contains
 * the changed configuration as defined by the language worker statically
 * in it's extension manifest.
 */
var DidChangeConfigurationNotification;
(function (DidChangeConfigurationNotification) {
    DidChangeConfigurationNotification.type = { method: 'workspace/didChangeConfiguration' };
})(DidChangeConfigurationNotification = exports.DidChangeConfigurationNotification || (exports.DidChangeConfigurationNotification = {}));
var MessageType;
(function (MessageType) {
    MessageType.Error = 1;
    MessageType.Warning = 2;
    MessageType.Info = 3;
    MessageType.Log = 4;
})(MessageType = exports.MessageType || (exports.MessageType = {}));
/**
 * The show message event is send from a worker to a client to ask
 * the client to display a particular message in the user interface
 */
var ShowMessageNotification;
(function (ShowMessageNotification) {
    ShowMessageNotification.type = { method: 'window/showMessage' };
})(ShowMessageNotification = exports.ShowMessageNotification || (exports.ShowMessageNotification = {}));
var LogMessageNotification;
(function (LogMessageNotification) {
    LogMessageNotification.type = { method: 'window/logMessage' };
})(LogMessageNotification = exports.LogMessageNotification || (exports.LogMessageNotification = {}));
/**
 * The document event is send from the client to the worker to signal
 * newly opened, changed and closed documents.
 */
var DidOpenTextDocumentNotification;
(function (DidOpenTextDocumentNotification) {
    DidOpenTextDocumentNotification.type = { method: 'textDocument/didOpen' };
})(DidOpenTextDocumentNotification = exports.DidOpenTextDocumentNotification || (exports.DidOpenTextDocumentNotification = {}));
var DidChangeTextDocumentNotification;
(function (DidChangeTextDocumentNotification) {
    DidChangeTextDocumentNotification.type = { method: 'textDocument/didChange' };
})(DidChangeTextDocumentNotification = exports.DidChangeTextDocumentNotification || (exports.DidChangeTextDocumentNotification = {}));
var DidCloseTextDocumentNotification;
(function (DidCloseTextDocumentNotification) {
    DidCloseTextDocumentNotification.type = { method: 'textDocument/didClose' };
})(DidCloseTextDocumentNotification = exports.DidCloseTextDocumentNotification || (exports.DidCloseTextDocumentNotification = {}));
var DidChangeFilesNotification;
(function (DidChangeFilesNotification) {
    DidChangeFilesNotification.type = { method: 'workspace/didChangeFiles' };
})(DidChangeFilesNotification = exports.DidChangeFilesNotification || (exports.DidChangeFilesNotification = {}));
var FileChangeType;
(function (FileChangeType) {
    FileChangeType.Created = 1;
    FileChangeType.Changed = 2;
    FileChangeType.Deleted = 3;
})(FileChangeType = exports.FileChangeType || (exports.FileChangeType = {}));
/**
 * Diagnostics notification are send from the worker to clients to signal
 * results of validation runs
 */
var PublishDiagnosticsNotification;
(function (PublishDiagnosticsNotification) {
    PublishDiagnosticsNotification.type = { method: 'document/publishDiagnostics' };
})(PublishDiagnosticsNotification = exports.PublishDiagnosticsNotification || (exports.PublishDiagnosticsNotification = {}));
var Severity;
(function (Severity) {
    Severity.Error = 0;
    Severity.Warning = 1;
    Severity.Information = 2;
    Severity.Hint = 3;
})(Severity = exports.Severity || (exports.Severity = {}));
